@@ -16,8 +16,7 @@
 """Facilities for automatically determining files' correct metadata.
 """
 
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
+from __future__ import division, absolute_import, print_function
 
 from beets import logging
 from beets import config
