@@ -67,7 +67,7 @@ class HumanReadableException(Exception):
         """Get the reason as a string."""
         if isinstance(self.reason, unicode):
             return self.reason
-        elif isinstance(self.reason, basestring):  # Byte string.
+        elif isinstance(self.reason, bytes):
             return self.reason.decode('utf8', 'ignore')
         elif hasattr(self.reason, 'strerror'):  # i.e., EnvironmentError
             return self.reason.strerror
@@ -158,8 +158,9 @@ def sorted_walk(path, ignore=(), ignore_hidden=False, logger=None):
     pattern in `ignore` are skipped. If `logger` is provided, then
     warning messages are logged there when a directory cannot be listed.
     """
-    # Make sure the path isn't a Unicode string.
+    # Make sure the pathes aren't Unicode strings.
     path = bytestring_path(path)
+    ignore = [bytestring_path(i) for i in ignore]
 
     # Get all the directories and files at this level.
     try:
@@ -264,6 +265,7 @@ def prune_dirs(path, root=None, clutter=('.DS_Store', 'Thumbs.db')):
         if not os.path.exists(directory):
             # Directory gone already.
             continue
+        clutter = [bytestring_path(c) for c in clutter]
         if fnmatch_all(os.listdir(directory), clutter):
             # Directory contains only clutter (or nothing).
             try:
@@ -334,6 +336,9 @@ def bytestring_path(path):
         return path.encode('utf8')
 
 
+PATH_SEP = bytestring_path(os.sep)
+
+
 def displayable_path(path, separator=u'; '):
     """Attempts to decode a bytestring path to a unicode object for the
     purpose of displaying it to the user. If the `path` argument is a
@@ -797,7 +802,7 @@ def _windows_long_path_name(short_path):
     long path given a short filename.
     """
     if not isinstance(short_path, unicode):
-        short_path = unicode(short_path)
+        short_path = short_path.decode(_fsencoding())
 
     import ctypes
     buf = ctypes.create_unicode_buffer(260)
