@@ -27,14 +27,15 @@ This is sort of like a tiny, horrible degeneration of a real templating
 engine like Jinja2 or Mustache.
 """
 
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
+from __future__ import division, absolute_import, print_function
 
 import re
 import ast
 import dis
 import types
 
+from .confit import NUMERIC_TYPES
+
 SYMBOL_DELIM = u'$'
 FUNC_DELIM = u'%'
 GROUP_OPEN = u'{'
@@ -42,8 +43,8 @@ GROUP_CLOSE = u'}'
 ARG_SEP = u','
 ESCAPE_CHAR = u'$'
 
-VARIABLE_PREFIX = b'__var_'
-FUNCTION_PREFIX = b'__func_'
+VARIABLE_PREFIX = '__var_'
+FUNCTION_PREFIX = '__func_'
 
 
 class Environment(object):
@@ -72,14 +73,14 @@ def ex_literal(val):
     value.
     """
     if val is None:
-        return ast.Name(b'None', ast.Load())
-    elif isinstance(val, (int, float, long)):
+        return ast.Name('None', ast.Load())
+    elif isinstance(val, NUMERIC_TYPES):
         return ast.Num(val)
     elif isinstance(val, bool):
         return ast.Name(bytes(val), ast.Load())
     elif isinstance(val, basestring):
         return ast.Str(val)
-    raise TypeError('no literal for {0}'.format(type(val)))
+    raise TypeError(u'no literal for {0}'.format(type(val)))
 
 
 def ex_varassign(name, expr):
@@ -125,7 +126,7 @@ def compile_func(arg_names, statements, name='_the_func', debug=False):
     mod = ast.Module([func_def])
     ast.fix_missing_locations(mod)
 
-    prog = compile(mod, b'<generated>', b'exec')
+    prog = compile(mod, '<generated>', 'exec')
 
     # Debug: show bytecode.
     if debug:
@@ -135,7 +136,7 @@ def compile_func(arg_names, statements, name='_the_func', debug=False):
                 dis.dis(const)
 
     the_locals = {}
-    exec prog in {}, the_locals
+    exec(prog, {}, the_locals)
     return the_locals[name]
 
 
@@ -208,11 +209,11 @@ class Call(object):
             # Create a subexpression that joins the result components of
             # the arguments.
             arg_exprs.append(ex_call(
-                ast.Attribute(ex_literal(u''), b'join', ast.Load()),
+                ast.Attribute(ex_literal(u''), 'join', ast.Load()),
                 [ex_call(
-                    b'map',
+                    'map',
                     [
-                        ex_rvalue(b'unicode'),
+                        ex_rvalue('unicode'),
                         ast.List(subexprs, ast.Load()),
                     ]
                 )],
@@ -558,7 +559,7 @@ class Template(object):
 
 # Performance tests.
 
-if __name__ == b'__main__':
+if __name__ == '__main__':
     import timeit
     _tmpl = Template(u'foo $bar %baz{foozle $bar barzle} $bar')
     _vars = {'bar': 'qux'}
@@ -571,4 +572,4 @@ if __name__ == b'__main__':
                               'from __main__ import _tmpl, _vars, _funcs',
                               number=10000)
     print(comp_time)
-    print('Speedup:', interp_time / comp_time)
+    print(u'Speedup:', interp_time / comp_time)
