@@ -16,8 +16,7 @@
 """Creates freedesktop.org-compliant .directory files on an album level.
 """
 
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
+from __future__ import division, absolute_import, print_function
 
 from beets.plugins import BeetsPlugin
 from beets import ui
@@ -25,13 +24,14 @@ from beets import ui
 
 class FreedesktopPlugin(BeetsPlugin):
     def commands(self):
-        deprecated = ui.Subcommand("freedesktop", help="Print a message to "
-                                   "redirect to thumbnails --dolphin")
+        deprecated = ui.Subcommand(
+            "freedesktop",
+            help=u"Print a message to redirect to thumbnails --dolphin")
         deprecated.func = self.deprecation_message
         return [deprecated]
 
     def deprecation_message(self, lib, opts, args):
-        ui.print_("This plugin is deprecated. Its functionality is superseded "
-                  "by the 'thumbnails' plugin")
-        ui.print_("'thumbnails --dolphin' replaces freedesktop. See doc & "
-                  "changelog for more information")
+        ui.print_(u"This plugin is deprecated. Its functionality is "
+                  u"superseded by the 'thumbnails' plugin")
+        ui.print_(u"'thumbnails --dolphin' replaces freedesktop. See doc & "
+                  u"changelog for more information")
