@@ -503,7 +503,7 @@ class Google(Backend):
         try:
             text = unicodedata.normalize('NFKD', text).encode('ascii',
                                                               'ignore')
-            text = unicode(re.sub('[-\s]+', ' ', text))
+            text = unicode(re.sub('[-\s]+', ' ', text.decode('utf-8')))
         except UnicodeDecodeError:
             self._log.exception(u"Failing to normalize '{0}'", text)
         return text
@@ -607,11 +607,14 @@ class LyricsPlugin(plugins.BeetsPlugin):
 
         if 'google' in sources:
             if not self.config['google_API_key'].get():
-                self._log.warn(u'To use the google lyrics source, you must '
-                               u'provide an API key in the configuration. '
-                               u'See the documentation for further details.')
+                # We log a *debug* message here because the default
+                # configuration includes `google`. This way, the source
+                # is silent by default but can be enabled just by
+                # setting an API key.
+                self._log.debug(u'Disabling google source: '
+                                u'no API key configured.')
                 sources.remove('google')
-            if not HAS_BEAUTIFUL_SOUP:
+            elif not HAS_BEAUTIFUL_SOUP:
                 self._log.warn(u'To use the google lyrics source, you must '
                                u'install the beautifulsoup4 module. See the '
                                u'documentation for further details.')
